@@ -3,13 +3,15 @@ Main interface for workmail service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workmail import WorkMailClient
+    from mypy_boto3_workmail import WorkMailClient
 
     session = boto3.Session()
 
     client: WorkMailClient = boto3.client("workmail")
     session_client: WorkMailClient = session.client("workmail")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
