@@ -3,8 +3,11 @@ Main interface for workmail service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workmail import (
+
+    from mypy_boto3_workmail import WorkMailClient
+    from mypy_boto3_workmail import (
         ListAliasesPaginator,
         ListGroupMembersPaginator,
         ListGroupsPaginator,
@@ -25,6 +28,7 @@ Usage::
     list_resource_delegates_paginator: ListResourceDelegatesPaginator = client.get_paginator("list_resource_delegates")
     list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
